*****************************************************
:mod:`mopidy.mixers.dummy` -- Dummy mixer for testing
*****************************************************

.. inheritance-diagram:: mopidy.mixers.dummy

.. automodule:: mopidy.mixers.dummy
    :synopsis: Dummy mixer for testing
    :members:
